Improve this doc

# Error: $location:ipthprfx
Invalid or Missing Path Prefix

    Invalid url "{0}", missing path prefix "{1}".

## Description

This error occurs when you configure the `$location` service in the html5 mode, specify a base url for your application via `<base>` element and try to update the location with a path that doesn't match the base prefix.

To resolve this issue, please check the base url specified via the `<base>` tag in the head of your main html document, as well as the url that you tried to set the location to.